@@ -97,6 +97,12 @@ typedef struct{
   unsigned int mUInt2;
 } SUIntUInt;
 
+/** used for reading the offset file */
+typedef struct{
+  unsigned int mUInt1;
+  streampos mStreampos;
+} SUIntStreampos;
+
 
 /***************************************
 *
@@ -286,7 +292,7 @@ bool CAcIFFileSystem::generateInvertedFile(){
       //writing the offset
       {
 	// this is the position of the next feature in the inverted file
-	unsigned int lPos=lNewInvertedFile.tellp();
+	streampos lPos(lNewInvertedFile.tellp());
 	
 	/* updating the offset file */
 
@@ -378,6 +384,7 @@ bool CAcIFFileSystem::generateInvertedFile(){
        << endl;
 
 
+
 #ifndef _NO_CHECK_CONSISTENCY
   cout << "BEFORE checking inverted file consistency" << flush;
   assert(checkConsistency());
@@ -394,13 +401,24 @@ bool CAcIFFileSystem::generateInvertedFile(){
     (helper function for inverted file construction)
 */
 void CAcIFFileSystem::writeOffsetFileElement(TID inFeatureID,
-					     int inPosition,
+					     streampos inPosition,
 					     ostream& inOpenOffsetFile){
-  /**/gMutex->lock();
-  inOpenOffsetFile.write((char*)&inFeatureID,
-			 sizeof(inFeatureID));
-  inOpenOffsetFile.write((char*)&inPosition,
-			 sizeof(inPosition));
+  /**/gMutex->lock();/** used for reading the offset file */
+
+  SUIntStreampos lWriter;
+
+  lWriter.mUInt1=inFeatureID;
+  lWriter.mStreampos=inPosition;
+
+//   inOpenOffsetFile.write((char*)&inFeatureID,
+// 			 sizeof(TID));
+//   inOpenOffsetFile.write((char*)&inPosition,
+// 			 sizeof(streampos));
+  inOpenOffsetFile.write((char*)&lWriter,
+ 			 sizeof(lWriter));
+  std::cout << "[inFeatureID:" << sizeof(TID) << "/" << inFeatureID
+	    << ";inPosition:" << sizeof(streampos) << "/" << inPosition 
+	    << "]" << endl;
   /**/gMutex->unlock();
   
 };
@@ -419,7 +437,7 @@ bool CAcIFFileSystem::newGenerateInvertedFile(){
   /**/gMutex->lock();
   // open the feature description file
   //
-  cout << "I want to use/generate the files:"
+  cout << "NEWGEN I want to use/generate the files:"
        << mInvertedFileName << endl
        << mOffsetFileName << endl
        << mURL2FTS->getURLToFeatureFileName() << endl
@@ -553,18 +571,19 @@ bool CAcIFFileSystem::newGenerateInvertedFile(){
        << flush
        << endl;
     
-  merge_sort_streams<CIFBuilderTriplet>(lAuxiliaryName1.c_str(),
-					lAuxiliaryName2.c_str());
+  string lLastFileUsed(merge_sort_streams<CIFBuilderTriplet>(lAuxiliaryName1.c_str(),
+							     lAuxiliaryName2.c_str()));
 
 
-  cout << "after mergesort " 
+  cout << "after mergesort. The last file I used was " 
+       << lLastFileUsed
        << flush
        << endl;
   
   
   /* now read the file  buildertriplet by buildertriplet.
      each time the ID changes, we are finished with one list */
-  ifstream lInAuxiliaryFile(string(mTemporaryIndexingFileBase+"gift-auxiliary-1").c_str());
+  ifstream lInAuxiliaryFile(lLastFileUsed.c_str());
 
   cout << "Opening sorted stream for reading. State (should be '1'): "
        << lInAuxiliaryFile
@@ -694,20 +713,20 @@ bool CAcIFFileSystem::newGenerateInvertedFile(){
   
   //as last thing give as output the Additional Document Information
   /* writes the additional document information */
-  cout << "WRITING ADI ****************************************"
+  cout << "NEW WRITING ADI ****************************************"
        << endl;
   assert(lADI.output());
-  cout << "ADI WRITTEN ****************************************"
+  cout << "NEW ADI WRITTEN ****************************************"
        << endl
        << endl;
   
   
-#ifndef _NO_CHECK_CONSISTENCY
   cout << "BEFORE checking inverted file consistency" << flush;
   assert(checkConsistency());
   cout << "AFTER checking inverted file consistency" << endl
        << "The check was successful"
        << endl;
+#ifndef _NO_CHECK_CONSISTENCY
 #endif
   
   // delete the helper files created by merge_sort_streams
@@ -962,14 +981,14 @@ bool CAcIFFileSystem::init(bool inMemory)
 
   /* while there is no end of file for the offsets */
   while(mOffsetFile){
-    SUIntUInt lVal;
+    SUIntStreampos lVal;
 
     /* read a value into the offset file */
     mOffsetFile.read((char*)&lVal,sizeof(lVal));
 
 
     unsigned int lFeatureID=lVal.mUInt1;
-    unsigned int lOffset=lVal.mUInt2;
+    streampos lOffset(lVal.mStreampos);//FIXME streampos
 
     if(mOffsetFile){
       mMaximumFeatureID=(mMaximumFeatureID < lFeatureID)?lFeatureID:mMaximumFeatureID;
@@ -977,20 +996,20 @@ bool CAcIFFileSystem::init(bool inMemory)
       mIDToOffset[lFeatureID]=lOffset;
     }
 
-#ifndef _NO_PRINT_OFFSET_CHECK
-    cout << "[lVal" << flush
+
+    cout << "[read:lVal" << flush
 	 << hex
 	 << lFeatureID
 	 << ","
-	 << hex
-	 << lOffset
 	 << dec
-	 << "]" << flush;
+	 << lOffset
+	 << "]" << endl;
+#ifndef _NO_PRINT_OFFSET_CHECK
 #endif
     //Reading the offsetfile
     {
       //move to the right position
-      mInvertedFile->seekg(streampos(lOffset));
+      mInvertedFile->seekg(lOffset);
 
       //read the list start chunk 
       //(by constructing an instance of the list start cunk)
@@ -1213,7 +1232,7 @@ FeatureToList(TFeatureID inFeatureID)const
 
       //Find the list of URL-IDs for the feature
       if(mIDToOffset.find(inFeatureID)!=mIDToOffset.end()){
-	mInvertedFile->seekg(streampos((*mIDToOffset.find(inFeatureID)).second));
+	mInvertedFile->seekg((*mIDToOffset.find(inFeatureID)).second);
       	assert(*mInvertedFile);
 	/* if the inverted file has been able to be opened */
 	if(*mInvertedFile){
@@ -1286,7 +1305,7 @@ bool CAcIFFileSystem::findWithinStream(TID inFeatureID,
 							  after the last one for a list */
     {
       /* seekg searches the file position to read (get) */
-      mInvertedFile->seekg(streampos((*mIDToOffset.find(inFeatureID)).second));
+      mInvertedFile->seekg((*mIDToOffset.find(inFeatureID)).second);
       
       /* if the file is correctly opened */
       if(*mInvertedFile){
@@ -1658,7 +1677,7 @@ unsigned int CAcIFFileSystem::getFeatureDescription(TID inID)const{
     /**/gMutex->unlock();  
     return lReturnValue;
   }else{
-    cout << "[UF: "
+    cout << "[UnknownFeature: "
 	 << inID
 	 << "]"
 	 << flush;
